# -*- coding: utf-8 -*-

''' Task to handle communication with driver.

Copyright (C) 2019 CAEN ELS s.r.l.

'''

from PyQt5.QtCore import *
import numpy as np

import DriverInterface as di


class TriggerThread(QThread):
    ''' This thread is polling the Trigger average data when in Trigger Mode '''

    newTriggerDataAvailable = pyqtSignal(np.ndarray, np.ndarray)

    def __init__(self, pico_path):
        super(TriggerThread, self).__init__()
        self.exiting = False
        self.data = np.zeros((16))
        self.cntr = np.zeros((2))
        self.drv = di.DriverInterface(pico_path, debug=False)

    def __del__(self):
        # print('TriggerThread __del__')
        self.wait()

    @pyqtSlot()
    def setExiting(self):
        ''' Qt Slot to gracefully terminate thread. '''
        self.exiting = True

    def run(self):
        ''' Infinite loop with sleep() to not overload the processor. '''
        while not self.exiting:
            tmp_f = float(0)
            tmp_i = int(0)
            for ind_i in range(16):
                self.data[ind_i] = self.drv.get_accumulator_data(tmp_f, ind_i)
            self.cntr[0] = self.drv.get_trg_cntr_1M(tmp_i)
            self.cntr[1] = self.drv.get_trg_cntr_1k(tmp_i)
            self.newTriggerDataAvailable.emit(self.data, self.cntr)

            self.msleep(500)
            # print('Hello from TriggerThread while loop')
